<?php
/**
 * Seven Sages functions and definitions
 *
 * @link https://developer.wordpress.org/themes/basics/theme-functions/
 *
 * @package Seven_Sages
 */

/**
 * Define constants
 */

define('SEVEN_SAGES_VERSION', '1.0.4');
define('SEVEN_SAGES_URI', get_template_directory_uri());
define('SEVEN_SAGES_DIR', get_template_directory());

if ( ! function_exists( 'seven_sages_setup' ) ) :
	/**
	 * Sets up theme defaults and registers support for various WordPress features.
	 *
	 * Note that this function is hooked into the after_setup_theme hook, which
	 * runs before the init hook. The init hook is too late for some features, such
	 * as indicating support for post thumbnails.
	 */
	function seven_sages_setup() {
		/*
		 * Make theme available for translation.
		 * Translations can be filed in the /languages/ directory.
		 * If you're building a theme based on Seven Sages, use a find and replace
		 * to change 'seven-sages' to the name of your theme in all the template files.
		 */
		load_theme_textdomain( 'seven-sages', SEVEN_SAGES_DIR . '/languages' );

		// Add default posts and comments RSS feed links to head.
		add_theme_support( 'automatic-feed-links' );

		/*
		 * Let WordPress manage the document title.
		 * By adding theme support, we declare that this theme does not use a
		 * hard-coded <title> tag in the document head, and expect WordPress to
		 * provide it for us.
		 */
		add_theme_support( 'title-tag' );

		/*
		 * Enable support for Post Thumbnails on posts and pages.
		 *
		 * @link https://developer.wordpress.org/themes/functionality/featured-images-post-thumbnails/
		 */
		add_theme_support( 'post-thumbnails' );

		// This theme uses wp_nav_menu() in one location.
		register_nav_menus( array(
			'menu-1' => esc_html__( 'Primary', 'seven-sages' ),
		) );

		/*
		 * Switch default core markup for search form, comment form, and comments
		 * to output valid HTML5.
		 */
		add_theme_support( 'html5', array(
			'search-form',
			'comment-form',
			'comment-list',
			'gallery',
			'caption',
		) );

		// Set up the WordPress core custom background feature.
		add_theme_support( 'custom-background', apply_filters( 'seven_sages_custom_background_args', array(
			'default-color' => '#f1f1f1',
			'default-image' => '',
		) ) );

		// Add theme support for selective refresh for widgets.
		add_theme_support( 'customize-selective-refresh-widgets' );

		/**
		 * Add support for core custom logo.
		 *
		 * @link https://codex.wordpress.org/Theme_Logo
		 */
		add_theme_support( 'custom-logo', array(
			'height'      => 250,
			'width'       => 250,
			'flex-width'  => true,
			'flex-height' => true,
		) );

		/**
         * Added starter content
         */
        add_theme_support(
            'starter-content', array(
                'widgets' => array(
                    'sidebar-1' => array(
                        'search',
                        'recent-posts',
                        'recent-comments',
                        'archives',
                        'categories',
                        'meta',
                    ),
                    'sidebar-2' => array(
                        'text_about',
                        'calendar',
                        'text_business_info',
                    ),
                ),
            )
        );
	}
endif;
add_action( 'after_setup_theme', 'seven_sages_setup' );

/**
 * Set the content width in pixels, based on the theme's design and stylesheet.
 *
 * Priority 0 to make it available to lower priority callbacks.
 *
 * @global int $content_width
 */
function seven_sages_content_width() {
	$GLOBALS['content_width'] = apply_filters( 'seven_sages_content_width', 640 );
}
add_action( 'after_setup_theme', 'seven_sages_content_width', 0 );

/**
 * Register widget area.
 *
 * @link https://developer.wordpress.org/themes/functionality/sidebars/#registering-a-sidebar
 */
function seven_sages_widgets_init() {
        register_sidebar(
            array(
            'name'          => esc_html__('Right Sidebar', 'seven-sages'),
            'id'            => 'sidebar-1',
            'description'   => esc_html__('Add widgets here.', 'seven-sages'),
            'before_widget' => '<section id="%1$s" class="widget %2$s">',
            'after_widget'  => '</section>',
            'before_title'  => '<h2 class="widget-title">',
            'after_title'   => '</h2>',
            )
        );
        register_sidebar(
            array(
            'name'          => esc_html__('Left Sidebar', 'seven-sages'),
            'id'            => 'sidebar-2',
            'description'   => esc_html__('Add widgets here.', 'seven-sages'),
            'before_widget' => '<section id="%1$s" class="widget %2$s">',
            'after_widget'  => '</section>',
            'before_title'  => '<h2 class="widget-title">',
            'after_title'   => '</h2>',
            )
        );
}
add_action( 'widgets_init', 'seven_sages_widgets_init' );

/**
 * Enqueue scripts and styles.
 */
function seven_sages_scripts() {
	wp_enqueue_style( 'seven-sages-style', get_stylesheet_uri() );

	wp_enqueue_script( 'seven-sages-navigation', SEVEN_SAGES_URI . '/assets/js/navigation.js', array( 'jquery' ), '20151215', true );

	wp_enqueue_script( 'seven-sages-skip-link-focus-fix', SEVEN_SAGES_URI . '/assets/js/skip-link-focus-fix.js', array(), '20151215', true );

	if ( is_singular() && comments_open() && get_option( 'thread_comments' ) ) {
		wp_enqueue_script( 'comment-reply' );
	}

	wp_enqueue_style('font-awesome', SEVEN_SAGES_URI . '/assets/css/min/font-awesome.min.css' );
}
add_action( 'wp_enqueue_scripts', 'seven_sages_scripts' );

/**
 * Implement the Custom Header feature.
 */
require SEVEN_SAGES_DIR . '/inc/custom-header.php';

/**
 * Custom template tags for this theme.
 */
require SEVEN_SAGES_DIR . '/inc/template-tags.php';

/**
 * Custom functions that act independently of the theme templates.
 */
require SEVEN_SAGES_DIR . '/inc/extras.php';

/**
 * Functions which enhance the theme by hooking into WordPress.
 */
require SEVEN_SAGES_DIR . '/inc/template-functions.php';

/**
 * Customizer additions.
 */
require SEVEN_SAGES_DIR . '/inc/customizer/customizer.php';

/**
 * Load Jetpack compatibility file.
 */
if ( defined( 'JETPACK__VERSION' ) ) {
	require SEVEN_SAGES_DIR . '/inc/jetpack.php';
}

